@@ -1,6 +1,6 @@
 package Devel::PatchPerl;
 {
-  $Devel::PatchPerl::VERSION = '1.00';
+  $Devel::PatchPerl::VERSION = '1.02';
 }
 
 # ABSTRACT: Patch perl source a la Devel::PPPort's buildperl.pl
@@ -110,6 +110,7 @@ my @patch = (
             ],
     subs => [
               [ \&_patch_conf_solaris ],
+              [ \&_patch_bitrig ],
               [ \&_patch_hints ],
             ],
   },
@@ -2130,11 +2131,56 @@ index 9bde518..45eb782 100644
 END
 }
 
+sub _patch_bitrig {
+  return unless $^O eq 'bitrig';
+  my $perlver = shift;
+  my $num = _norm_ver( $perlver );
+  return unless $num < 5.019004;
+  _patch(<<'BOOGLE');
+diff --git a/Configure b/Configure
+index 19bed50..e4e4075 100755
+--- a/Configure
++++ b/Configure
+@@ -3312,6 +3312,9 @@ EOM
+ 			;;
+ 		next*) osname=next ;;
+ 		nonstop-ux) osname=nonstopux ;;
++		bitrig) osname=bitrig
++			osvers="$3"
++			;;
+ 		openbsd) osname=openbsd
+                 	osvers="$3"
+                 	;;
+@@ -8328,7 +8331,7 @@ if "$useshrplib"; then
+ 	solaris)
+ 		xxx="-R $shrpdir"
+ 		;;
+-	freebsd|mirbsd|netbsd|openbsd|interix|dragonfly)
++	freebsd|mirbsd|netbsd|openbsd|interix|dragonfly|bitrig)
+ 		xxx="-Wl,-R$shrpdir"
+ 		;;
+ 	bsdos|linux|irix*|dec_osf|gnu*)
+diff --git a/Makefile.SH b/Makefile.SH
+index 17298fa..ecaa8ac 100755
+--- a/Makefile.SH
++++ b/Makefile.SH
+@@ -77,7 +77,7 @@ true)
+ 	sunos*)
+ 		linklibperl="-lperl"
+ 		;;
+-	netbsd*|freebsd[234]*|openbsd*|dragonfly*)
++	netbsd*|freebsd[234]*|openbsd*|dragonfly*|bitrig*)
+ 		linklibperl="-L. -lperl"
+ 		;;
+ 	interix*)
+BOOGLE
+}
+
 sub _patch_conf_solaris {
   return unless $^O eq 'solaris';
   my $perlver = shift;
-  my $num = eval "v$perlver";
-  return unless $num lt eval "v5.18.0";
+  my $num = _norm_ver( $perlver );
+  return unless $num < 5.018000;
   _patch(<<'BUBBLE');
 diff --git a/Configure b/Configure
 index ff511d3..30ab78a 100755
@@ -2246,6 +2292,13 @@ index 2244fdf..9a9b5f5 100644
 BOBBLE
 }
 
+sub _norm_ver {
+  my $ver = shift;
+  my @v = split(qr/[._]0*/, $_);
+  $v[2] ||= 0;
+  return sprintf '%d.%03d%03d', @v;
+}
+
 qq[patchin'];
 
 __END__
@@ -2258,7 +2311,7 @@ Devel::PatchPerl - Patch perl source a la Devel::PPPort's buildperl.pl
 
 =head1 VERSION
 
-version 1.00
+version 1.02
 
 =head1 SYNOPSIS
 
